/**
  ******************************************************************************
  * @file    ili9325_lcd_gpio_driver.h
  * @author  Waveshare
  * @version V1.1
  * @date    19-December-2016
  * @brief   Header file of ILI9325 LCD GPIO Driver.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2016 Waveshare </center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of Waveshare nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************  
  */ 
#ifndef __GLCD_H 
#define __GLCD_H

/* Includes ------------------------------------------------------------------*/
#include <math.h>
#include "stm32f1xx_hal.h"
#include "fonts.h"

/* Private define ------------------------------------------------------------*/
#define USE_16BIT_PMP

/*********************************************************************
* Overview: Horizontal and vertical display resolution
*********************************************************************/
//#define DISP_HOR_RESOLUTION        320
//#define DISP_VER_RESOLUTION        240

//#define DISP_ORIENTATION          0
#define DISP_ORIENTATION          90
//#define DISP_ORIENTATION          180
//#define DISP_ORIENTATION          270

/* Private define ------------------------------------------------------------*/

#if  ( DISP_ORIENTATION == 90 ) || ( DISP_ORIENTATION == 270 )

#define  MAX_X  320
#define  MAX_Y  240   

#elif  ( DISP_ORIENTATION == 0 ) || ( DISP_ORIENTATION == 180 )

#define  MAX_X  240
#define  MAX_Y  320   

#endif

/*********************************************************************
* Overview: Horizontal synchronization timing in pixels
*********************************************************************/
//#define DISP_HOR_PULSE_WIDTH    20    /* 20 */
//#define DISP_HOR_BACK_PORCH      51    /* 48  */
//#define DISP_HOR_FRONT_PORCH    20    /* 20 */

/*********************************************************************
* Overview: Vertical synchronization timing in lines
*********************************************************************/
//#define DISP_VER_PULSE_WIDTH    2    /* 2 */
//#define DISP_VER_BACK_PORCH      12    /* 16 */
//#define DISP_VER_FRONT_PORCH    4    /* 4 */

#define LCD_CS_SET()          (LCD_CS_GPIO_Port->BSRR = LCD_CS_Pin)
#define LCD_CS_RESET()        (LCD_CS_GPIO_Port->BRR = LCD_CS_Pin)

#define LCD_RS_SET()          (LCD_RS_GPIO_Port->BSRR = LCD_RS_Pin)
#define LCD_RS_RESET()        (LCD_RS_GPIO_Port->BRR = LCD_RS_Pin)

#define LCD_WR_SET()          (LCD_WR_GPIO_Port->BSRR = LCD_WR_Pin)
#define LCD_WR_RESET()        (LCD_WR_GPIO_Port->BRR = LCD_WR_Pin)

#define LCD_RD_SET()          (LCD_RD_GPIO_Port->BSRR = LCD_RD_Pin)
#define LCD_RD_RESET()        (LCD_RD_GPIO_Port->BRR = LCD_RD_Pin)

#define LCD_GPIO              GPIOB

/* LCD color */
#define WHITE          0xFFFF
#define BLACK          0x0000
#define GREY           0xF7DE
#define BLUE           0x001F
#define RED            0xF800
#define MAGENTA        0xF81F
#define GREEN          0x07E0
#define CYAN           0x7FFF
#define YELLOW         0xFFE0

#define RGB565CONVERT(red, green, blue) (int) (((red >> 3) << 11) | ((green >> 2) << 5) | (blue >> 3))
  


/* Private function prototypes -----------------------------------------------*/
void LCD_Initializtion(void);
void LCD_Clear(uint16_t Color);  
uint16_t LCD_GetPoint(uint16_t Xpos, uint16_t Ypos);
void LCD_SetPoint(uint16_t Xpos, uint16_t Ypos, uint16_t point);
void PutChar(uint16_t Xpos, uint16_t Ypos, uint8_t c, uint16_t charColor, sFONT *font, uint16_t bkColor);
void LCD_Box(uint16_t color ,uint16_t x0, uint16_t y0, uint16_t x1, uint16_t y1);
void GUI_Text(uint16_t Xpos, uint16_t Ypos, uint8_t *str, uint16_t Color, sFONT *font, uint16_t bkColor);
void LCD_DrawPicture(uint16_t StartX, uint16_t StartY, uint16_t EndX, uint16_t EndY, uint16_t *pic);
void LCD_SelectReg(uint16_t index);
void LCD_WriteData(uint16_t data);
uint16_t LCD_ReadData(void);
uint16_t LCD_ReadReg(uint16_t LCD_Reg);
void LCD_WriteReg(uint16_t LCD_Reg, uint16_t LCD_RegValue);
static void LCD_SetCursor( uint16_t Xpos, uint16_t Ypos );
/* Replace the delay_ms function with the HAL_Delay */
#define delay_ms(ms) HAL_Delay(ms)

#endif 

/*********************************************************************************************************
      END FILE
*********************************************************************************************************/

